==> react-lds-8.7.0.tgz: package/es/components/Accordion/Accordion.js <==
import "core-js/modules/es6.object.assign";
import "core-js/modules/es6.string.iterator";
import "core-js/modules/es6.array.from";
import "core-js/modules/es6.regexp.to-string";
import "core-js/modules/es7.symbol.async-iterator";
import "core-js/modules/es6.symbol";
import "core-js/modules/es6.object.set-prototype-of";
import "core-js/modules/web.dom.iterable";
import "core-js/modules/es6.array.iterator";
import "core-js/modules/es6.object.to-string";
import "core-js/modules/es6.object.keys";
import "core-js/modules/es7.array.includes";
import "core-js/modules/es6.string.includes";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import omit from 'lodash-es/omit'; // https://github.com/oliviertassinari/babel-plugin-transform-react-remove-prop-types#is-it-safe

var propTypes = {
  /**
   * sections
   */
  children: PropTypes.node.isRequired,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
    * which section(s) should be open by default, defaults to first
    */
  defaultOpen: PropTypes.oneOfType([PropTypes.string, PropTypes.arrayOf(PropTypes.string)]),

  /**
   * support opening multiple sections simultaneously
   */
  multiple: PropTypes.bool,

  /**
    * wraps the component in a card
    */
  styled: PropTypes.bool,

  /*
   * controlled mode: id(s) of open section(s)
   */
  open: PropTypes.oneOfType([PropTypes.string, PropTypes.arrayOf(PropTypes.string)]),

  /*
   * controlled mode: section click handler
   */
  onSectionClick: PropTypes.func
};

var Accordion =
/*#__PURE__*/
function (_Component) {
  _inherits(Accordion, _Component);

  function Accordion(props) {
    var _this;

    _classCallCheck(this, Accordion);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Accordion).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleClick", function (id) {
      var _this$props = _this.props,
          open = _this$props.open,
          onSectionClick = _this$props.onSectionClick,
          multiple = _this$props.multiple;

      if (open !== null) {
        // controlled
        onSectionClick(id);
        return;
      } // uncontrolled


      _this.setState(function (_ref) {
        var activeSections = _ref.activeSections;

        if (!activeSections.includes(id)) {
          if (multiple) return {
            activeSections: [].concat(_toConsumableArray(activeSections), [id])
          };
          return {
            activeSections: [id]
          };
        }

        return {
          activeSections: activeSections.filter(function (a) {
            return a !== id;
          })
        };
      });
    });

    var children = props.children,
        defaultOpen = props.defaultOpen,
        _open = props.open;

    if (_open === null) {
      // controlled
      if (defaultOpen) {
        if (typeof defaultOpen === 'string') {
          _this.state = {
            activeSections: [defaultOpen]
          };
        } else {
          // is array of strings
          _this.state = {
            activeSections: defaultOpen
          };
        }
      } else {
        _this.state = {
          activeSections: [children[0].props.id]
        };
      }
    }

    return _this;
  }

  _createClass(Accordion, [{
    key: "renderSections",
    value: function renderSections() {
      var _this2 = this;

      var _this$props2 = this.props,
          children = _this$props2.children,
          open = _this$props2.open;
      var activeSections = open || this.state.activeSections; // eslint-disable-line react/destructuring-assignment

      if (typeof activeSections === 'string') {
        activeSections = [activeSections];
      }

      var sections = children.map(function (child) {
        return React.cloneElement(child, {
          key: child.props.id,
          isOpen: activeSections.includes(child.props.id),
          onClick: function onClick() {
            return _this2.handleClick(child.props.id);
          }
        });
      });
      return sections;
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          className = _this$props3.className,
          styled = _this$props3.styled;
      var rest = omit(this.props, Object.keys(propTypes));
      var sldsClasses = ['slds-accordion', className];

      if (styled) {
        return React.createElement("div", {
          className: "slds-card"
        }, React.createElement("ul", _extends({}, rest, {
          className: cx(sldsClasses)
        }), this.renderSections()));
      }

      return React.createElement("ul", _extends({}, rest, {
        className: cx(sldsClasses)
      }), this.renderSections());
    }
  }]);

  return Accordion;
}(Component);

_defineProperty(Accordion, "defaultProps", {
  className: null,
  styled: false,
  defaultOpen: null,
  multiple: false,
  open: null,
  onSectionClick: null
});

Accordion.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
export default Accordion;

==> react-lds-9.1.0.tgz: package/es/components/Accordion/Accordion.js <==
import "core-js/modules/es.symbol";
import "core-js/modules/es.symbol.description";
import "core-js/modules/es.symbol.iterator";
import "core-js/modules/es.array.concat";
import "core-js/modules/es.array.filter";
import "core-js/modules/es.array.from";
import "core-js/modules/es.array.includes";
import "core-js/modules/es.array.iterator";
import "core-js/modules/es.array.map";
import "core-js/modules/es.date.to-string";
import "core-js/modules/es.object.assign";
import "core-js/modules/es.object.get-prototype-of";
import "core-js/modules/es.object.keys";
import "core-js/modules/es.object.set-prototype-of";
import "core-js/modules/es.object.to-string";
import "core-js/modules/es.regexp.to-string";
import "core-js/modules/es.string.includes";
import "core-js/modules/es.string.iterator";
import "core-js/modules/web.dom-collections.iterator";

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance"); }

function _iterableToArray(iter) { if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';
import omit from 'lodash-es/omit'; // https://github.com/oliviertassinari/babel-plugin-transform-react-remove-prop-types#is-it-safe

var propTypes = {
  /**
   * sections
   */
  children: PropTypes.node.isRequired,

  /**
   * class name
   */
  className: PropTypes.string,

  /**
    * which section(s) should be open by default, defaults to first
    */
  defaultOpen: PropTypes.oneOfType([PropTypes.string, PropTypes.arrayOf(PropTypes.string)]),

  /**
   * support opening multiple sections simultaneously
   */
  multiple: PropTypes.bool,

  /**
    * wraps the component in a card
    */
  styled: PropTypes.bool,

  /*
   * controlled mode: id(s) of open section(s)
   */
  open: PropTypes.oneOfType([PropTypes.string, PropTypes.arrayOf(PropTypes.string)]),

  /*
   * controlled mode: section click handler
   */
  onSectionClick: PropTypes.func
};

var Accordion =
/*#__PURE__*/
function (_Component) {
  _inherits(Accordion, _Component);

  function Accordion(props) {
    var _this;

    _classCallCheck(this, Accordion);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Accordion).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "handleClick", function (id) {
      var _this$props = _this.props,
          open = _this$props.open,
          onSectionClick = _this$props.onSectionClick,
          multiple = _this$props.multiple;

      if (open !== null) {
        // controlled
        onSectionClick(id);
        return;
      } // uncontrolled


      _this.setState(function (_ref) {
        var activeSections = _ref.activeSections;

        if (!activeSections.includes(id)) {
          if (multiple) return {
            activeSections: [].concat(_toConsumableArray(activeSections), [id])
          };
          return {
            activeSections: [id]
          };
        }

        return {
          activeSections: activeSections.filter(function (a) {
            return a !== id;
          })
        };
      });
    });

    var children = props.children,
        defaultOpen = props.defaultOpen,
        _open = props.open;

    if (_open === null) {
      // controlled
      if (defaultOpen) {
        if (typeof defaultOpen === 'string') {
          _this.state = {
            activeSections: [defaultOpen]
          };
        } else {
          // is array of strings
          _this.state = {
            activeSections: defaultOpen
          };
        }
      } else {
        _this.state = {
          activeSections: [children[0].props.id]
        };
      }
    }

    return _this;
  }

  _createClass(Accordion, [{
    key: "renderSections",
    value: function renderSections() {
      var _this2 = this;

      var _this$props2 = this.props,
          children = _this$props2.children,
          open = _this$props2.open;
      var activeSections = open || this.state.activeSections; // eslint-disable-line react/destructuring-assignment

      if (typeof activeSections === 'string') {
        activeSections = [activeSections];
      }

      var sections = children.map(function (child) {
        return React.cloneElement(child, {
          key: child.props.id,
          isOpen: activeSections.includes(child.props.id),
          onClick: function onClick() {
            return _this2.handleClick(child.props.id);
          }
        });
      });
      return sections;
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props3 = this.props,
          className = _this$props3.className,
          styled = _this$props3.styled;
      var rest = omit(this.props, Object.keys(propTypes));
      var sldsClasses = ['slds-accordion', className];

      if (styled) {
        return React.createElement("div", {
          className: "slds-card"
        }, React.createElement("ul", _extends({}, rest, {
          className: cx(sldsClasses)
        }), this.renderSections()));
      }

      return React.createElement("ul", _extends({}, rest, {
        className: cx(sldsClasses)
      }), this.renderSections());
    }
  }]);

  return Accordion;
}(Component);

_defineProperty(Accordion, "defaultProps", {
  className: null,
  styled: false,
  defaultOpen: null,
  multiple: false,
  open: null,
  onSectionClick: null
});

Accordion.propTypes = process.env.NODE_ENV !== "production" ? propTypes : {};
export default Accordion;
